Class: Rev::Input

Inherits:
ApiSerializable show all
Defined in:
lib/rev-api/models/order_request.rb

Overview

Input for order (aka source file)

Instance Attribute Summary collapse

Method Summary

Methods inherited from ApiSerializable

#initialize, #to_hash, #to_json

Constructor Details

This class inherits a constructor from Rev::ApiSerializable

Instance Attribute Details

#audio_length_secondsObject (readonly)

Length of audio in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::TranscriptionInfo



160
161
162
# File 'lib/rev-api/models/order_request.rb', line 160

def audio_length_seconds
  @audio_length_seconds
end

External URL, if sources wasn’t POSTed as input (YouTube, Vimeo, Dropbox, etc)



171
172
173
# File 'lib/rev-api/models/order_request.rb', line 171

def external_link
  @external_link
end

#uriObject (readonly)

Mandatory, URI of the media, as returned from the call to POST /inputs. :external_link might substitute :uri for Transcription or Caption.



168
169
170
# File 'lib/rev-api/models/order_request.rb', line 168

def uri
  @uri
end

#video_length_secondsObject (readonly)

Length of video in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::CaptionInfo



164
165
166
# File 'lib/rev-api/models/order_request.rb', line 164

def video_length_seconds
  @video_length_seconds
end