Class: Rev::OrderRequest

Inherits:
ApiSerializable show all
Defined in:
lib/rev-api/models/order_request.rb

Overview

OrderRequest is used for constructing order ‘spec’ in consumer code and passing it into. It consists of three main elements: :payment, :transcription_options and :notification. You can also supply priority, reference number, and customer comment

Constant Summary collapse

PRIORITY =

use to correctly set priority

{
  :normal => 'Normal',
  :time_insensitivie => 'TimeInsensitivie'
}

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiSerializable

#to_hash, #to_json

Constructor Details

#initialize(fields = {}) ⇒ OrderRequest

Returns a new instance of OrderRequest.

Parameters:

  • fields (Hash) (defaults to: {})

    of fields to initialize instance. See instance attributes for available fields.



50
51
52
53
54
# File 'lib/rev-api/models/order_request.rb', line 50

def initialize(fields = {})
  fields = { :priority => PRIORITY[:normal] }.merge(fields)
  @payment = Rev::Payment.
  super fields
end

Instance Attribute Details

#caption_optionsObject (readonly)



20
21
22
# File 'lib/rev-api/models/order_request.rb', line 20

def caption_options
  @caption_options
end

#client_refObject (readonly)

a reference number for the order meaningful for the client (optional)



26
27
28
# File 'lib/rev-api/models/order_request.rb', line 26

def client_ref
  @client_ref
end

#commentObject (readonly)

a comment with any special messages about the order (optional)



29
30
31
# File 'lib/rev-api/models/order_request.rb', line 29

def comment
  @comment
end

#notificationObject (readonly)



23
24
25
# File 'lib/rev-api/models/order_request.rb', line 23

def notification
  @notification
end

#paymentObject (readonly)

see Payment



11
12
13
# File 'lib/rev-api/models/order_request.rb', line 11

def payment
  @payment
end

#priorityObject (readonly)

a requested priority for the order, defaults to normal (optional)



32
33
34
# File 'lib/rev-api/models/order_request.rb', line 32

def priority
  @priority
end

#transcription_optionsObject (readonly)



14
15
16
# File 'lib/rev-api/models/order_request.rb', line 14

def transcription_options
  @transcription_options
end

#translation_optionsObject (readonly)



17
18
19
# File 'lib/rev-api/models/order_request.rb', line 17

def translation_options
  @translation_options
end

Class Method Details

.new_with_payment(payment, fields = {}) ⇒ Object

Deprecated.

payment always defaults to :account_balance

Parameters:

  • payment (Payment)

    payment info

  • fields (Hash) (defaults to: {})

    of fields to initialize instance. See instance attributes for available fields.



43
44
45
46
47
# File 'lib/rev-api/models/order_request.rb', line 43

def self.new_with_payment(payment, fields = {})
  fields = { :priority => PRIORITY[:normal] }.merge(fields)
  super fields
  @payment = payment
end