Class: Rev::TranslationOptions

Inherits:
InputOptions show all
Defined in:
lib/rev-api/models/order_request.rb

Overview

Translation options. This section contains the input media that must be transferred to our servers using a POST to /inputs, and are referenced using the URIs returned by that call. For each media, word count must be specified. The language code for the source and desitination languages must also be specified.

Instance Attribute Summary collapse

Attributes inherited from InputOptions

#inputs

Instance Method Summary collapse

Methods inherited from ApiSerializable

#to_hash, #to_json

Constructor Details

#initialize(inputs, info = {}) ⇒ TranslationOptions

Note:

Returns a new instance of TranslationOptions.

Parameters:

  • inputs (Array)

    list of inputs

  • info (Hash) (defaults to: {})

    of fields to initialize instance. May contain:

    • :source_language_code

    • :destination_language_code



143
144
145
# File 'lib/rev-api/models/order_request.rb', line 143

def initialize(inputs, info = {})
  super inputs, info
end

Instance Attribute Details

#destination_language_codeObject (readonly)

Mandatory, destination language code



136
137
138
# File 'lib/rev-api/models/order_request.rb', line 136

def destination_language_code
  @destination_language_code
end

#source_language_codeObject (readonly)

Mandatory, source language code



133
134
135
# File 'lib/rev-api/models/order_request.rb', line 133

def source_language_code
  @source_language_code
end