Class: Rev::Input

Inherits:
ApiSerializable show all
Defined in:
lib/rev-api/models/order_request.rb

Overview

Input for order (aka source file)

Instance Attribute Summary collapse

Method Summary

Methods inherited from ApiSerializable

#initialize, #to_hash, #to_json

Constructor Details

This class inherits a constructor from Rev::ApiSerializable

Instance Attribute Details

#audio_length_secondsObject (readonly)

Length of audio in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::TranscriptionInfo



194
195
196
# File 'lib/rev-api/models/order_request.rb', line 194

def audio_length_seconds
  @audio_length_seconds
end

External URL, if sources wasn’t POSTed as input (YouTube, Vimeo, Dropbox, etc)



205
206
207
# File 'lib/rev-api/models/order_request.rb', line 205

def external_link
  @external_link
end

#uriObject (readonly)

Mandatory, URI of the media, as returned from the call to POST /inputs. :external_link might substitute :uri for Transcription or Caption.



202
203
204
# File 'lib/rev-api/models/order_request.rb', line 202

def uri
  @uri
end

#video_length_secondsObject (readonly)

Length of video in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::CaptionInfo



198
199
200
# File 'lib/rev-api/models/order_request.rb', line 198

def video_length_seconds
  @video_length_seconds
end

#word_lengthObject (readonly)

Mandatory when used with OrderRequest::TranslationInfo, length of document, in words



190
191
192
# File 'lib/rev-api/models/order_request.rb', line 190

def word_length
  @word_length
end