Class: Rev::Input
- Inherits:
-
ApiSerializable
- Object
- ApiSerializable
- Rev::Input
- Defined in:
- lib/rev-api/models/order_request.rb
Overview
Input for order (aka source file)
Instance Attribute Summary collapse
-
#audio_length_seconds ⇒ Object
readonly
Length of audio in seconds (mandatory in case of inability to determine it automatically).
-
#external_link ⇒ Object
readonly
External URL, if sources wasn’t POSTed as input (YouTube, Vimeo, Dropbox, etc).
-
#uri ⇒ Object
readonly
Mandatory, URI of the media, as returned from the call to POST /inputs.
-
#video_length_seconds ⇒ Object
readonly
Length of video in seconds (mandatory in case of inability to determine it automatically).
-
#word_length ⇒ Object
readonly
Mandatory when used with OrderRequest::TranslationInfo, length of document, in words.
Method Summary
Methods inherited from ApiSerializable
#initialize, #to_hash, #to_json
Constructor Details
This class inherits a constructor from Rev::ApiSerializable
Instance Attribute Details
#audio_length_seconds ⇒ Object (readonly)
Length of audio in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::TranscriptionInfo
183 184 185 |
# File 'lib/rev-api/models/order_request.rb', line 183 def audio_length_seconds @audio_length_seconds end |
#external_link ⇒ Object (readonly)
External URL, if sources wasn’t POSTed as input (YouTube, Vimeo, Dropbox, etc)
194 195 196 |
# File 'lib/rev-api/models/order_request.rb', line 194 def external_link @external_link end |
#uri ⇒ Object (readonly)
Mandatory, URI of the media, as returned from the call to POST /inputs. :external_link might substitute :uri for Transcription or Caption.
191 192 193 |
# File 'lib/rev-api/models/order_request.rb', line 191 def uri @uri end |
#video_length_seconds ⇒ Object (readonly)
Length of video in seconds (mandatory in case of inability to determine it automatically). Used within OrderRequest::CaptionInfo
187 188 189 |
# File 'lib/rev-api/models/order_request.rb', line 187 def video_length_seconds @video_length_seconds end |
#word_length ⇒ Object (readonly)
Mandatory when used with OrderRequest::TranslationInfo, length of document, in words
179 180 181 |
# File 'lib/rev-api/models/order_request.rb', line 179 def word_length @word_length end |