Class: Rev::TranslationOptions
- Inherits:
-
InputOptions
- Object
- ApiSerializable
- InputOptions
- Rev::TranslationOptions
- Defined in:
- lib/rev-api/models/order_request.rb
Overview
Translation options. This section contains the input media that must be transferred to our servers using a POST to /inputs, and are referenced using the URIs returned by that call. For each media, word count must be specified. The language code for the source and desitination languages must also be specified.
Instance Attribute Summary collapse
-
#destination_language_code ⇒ Object
readonly
Mandatory, destination language code.
-
#source_language_code ⇒ Object
readonly
Mandatory, source language code.
Attributes inherited from InputOptions
Instance Method Summary collapse
-
#initialize(inputs, info = {}) ⇒ TranslationOptions
constructor
A new instance of TranslationOptions.
Methods inherited from ApiSerializable
Constructor Details
#initialize(inputs, info = {}) ⇒ TranslationOptions
Note:
For language codes refer to www.loc.gov/standards/iso639-2/php/code_list.php
Returns a new instance of TranslationOptions.
143 144 145 |
# File 'lib/rev-api/models/order_request.rb', line 143 def initialize(inputs, info = {}) super inputs, info end |
Instance Attribute Details
#destination_language_code ⇒ Object (readonly)
Mandatory, destination language code
136 137 138 |
# File 'lib/rev-api/models/order_request.rb', line 136 def destination_language_code @destination_language_code end |
#source_language_code ⇒ Object (readonly)
Mandatory, source language code
133 134 135 |
# File 'lib/rev-api/models/order_request.rb', line 133 def source_language_code @source_language_code end |